@@ -16,7 +16,7 @@ from beanstalk.console.titles import section_title, tool_title, separator
 from beanstalk.validator import validate_web_server, validate_file_existence, validate_project_type, supported_projects
 
 
-@task
+@beanstalk_task(beanstalk_role='app')
 def web_server(*servers):
     """Set targeted web server
     :param servers: list of severs (IP, CIDR, or domain name)
@@ -231,6 +231,7 @@ def deploy(settings_path=None, **settings_patches):
 
 
 @beanstalk_task(beanstalk_role='app')
+@roles('web_servers')
 def deploy_remote_core():
     """ The part to run on each server
     """
