@@ -3,7 +3,7 @@ import sys
 from fabric.api import *
 from fabric.colors import *
 from beanstalk import BEANSTALK_GLOBAL_BASE_PATH
-from beanstalk.decorators import beanstalk_role
+from beanstalk.decorators import beanstalk_task
 from beanstalk.tasks.utils import load_role_settings
 
 _screen_width = 67
@@ -15,10 +15,11 @@ def _result(success, hint):
     return ' ' * spaces + '[{status}]'.format(status=status)
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 @with_settings(hide('running', 'status'))
 def start():
+    """Start the uwsgi as a daemon
+    """
     hint = 'Start beanstalk:'
     sys.stdout.write(hint)
 
@@ -46,10 +47,11 @@ def start():
     sys.stdout.write('\n')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 @with_settings(hide('running', 'status'))
 def stop():
+    """Stop the uwsgi daemon
+    """
     hint = 'Stop beanstalk:'
     sys.stdout.write(hint)
 
@@ -74,10 +76,11 @@ def stop():
     sys.stdout.write('\n')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 @with_settings(hide('running', 'status'))
 def reload():
+    """Reload the uwsgi daemon
+    """
     hint = 'Reload beanstalk:'
     sys.stdout.write(hint)
 
@@ -97,17 +100,12 @@ def reload():
     sys.stdout.write('\n')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 @with_settings(hide('running', 'status'))
 def restart():
+    """Restart the uwsgi daemon
+    """
     print 'Restarting beanstalk-stack:'
     with settings(hide('warnings', 'status', 'running'), warn_only=True):
         execute(stop)
         execute(start)
-
-
-@task
-@with_settings(hide('running', 'status'))
-def usage():
-    print 'Usage: {start|stop|reload|restart}'
